@@ -1,7 +1,12 @@
+import logging
+
+from magnus import defaults
 from magnus.integration import BaseIntegration
 
+logger = logging.getLogger(defaults.NAME)
 
-class KfPComputeBufferedRunLogStore(BaseIntegration):
+
+class BufferedRunLogStore(BaseIntegration):
     """
     Only local execution mode is possible for Buffered Run Log store
     """
@@ -13,7 +18,7 @@ class KfPComputeBufferedRunLogStore(BaseIntegration):
         raise Exception('KFP cannot run work with buffered run log store')
 
 
-class KfPComputeFileSystemRunLogStore(BaseIntegration):
+class FileSystemRunLogStore(BaseIntegration):
     """
     Only local execution mode is possible for Buffered Run Log store
     """
@@ -22,10 +27,13 @@ class KfPComputeFileSystemRunLogStore(BaseIntegration):
     service_provider = 'file-system'  # The actual implementation of the service
 
     def validate(self, **kwargs):
-        raise Exception('KFP cannot run work with file system as run log store')
+        msg = (
+            "KFP cannot run work with file-system run log store. Unless you have made a mechanism to use volume mounts"
+        )
+        logger.warning(msg)
 
 
-class KfPComputeFileSystemCatalog(BaseIntegration):
+class FileSystemCatalog(BaseIntegration):
     """
     Only local execution mode is possible for Buffered Run Log store
     """
@@ -34,4 +42,7 @@ class KfPComputeFileSystemCatalog(BaseIntegration):
     service_provider = 'file-system'  # The actual implementation of the service
 
     def validate(self, **kwargs):
-        raise Exception('KFP cannot run work with file system catalog')
+        msg = (
+            "KFP cannot run work with file-system catalog. Unless you have made a mechanism to use volume mounts"
+        )
+        logger.warning(msg)
